<template>
  <ProTabs
    v-model="queryState.mineSignType"
    name="home-tab"
    :showPaneContent="false"
    class="home-tabs"
    isTransparent
    title-gutter="12"
    title-scroll
  >
    <ProTabPane :title="`全部`" :pane-key="0"></ProTabPane>
    <ProTabPane :title="`待确认`" :pane-key="10"></ProTabPane>
    <ProTabPane :title="`待签约`" :pane-key="20"></ProTabPane>
  </ProTabs>
  <InfiniteLoading
    scrollViewClassName="common-infinite-scroll-list home-list"
    v-bind="infiniteLoadingProps"
    :key="queryState.mineSignType"
  >
    <template #renderItem="{ item }">
      <TaskCard @click="goTaskDetail(item)">
        <template #actions>
          <div class="task-card-actions-text" :style="{ color: TaskStatusColor[10] }">
            {{ TaskStatusText[10] }}
          </div>
        </template>
      </TaskCard>
    </template>
  </InfiniteLoading>
</template>

<script setup lang="ts">
import { TaskCard, ProTabs, ProTabPane } from '@12333/components';
import { useUserStore } from '@/stores/modules/user';
import { TaskStatusText, TaskStatusColor, TaskStatus } from '@/constants';
import { useInfiniteLoading } from '@12333/hooks';
import { OrderInputType } from '@12333/constants';
import * as orderServices from '@12333/services/api/Order';
import Taro from '@tarojs/taro';

defineOptions({
  name: 'InnerPage',
});

const queryState = reactive({
  mineSignType: TaskStatus.All,
});

const userStore = useUserStore();

const { infiniteLoadingProps } = useInfiniteLoading(
  ({ pageParam }) => {
    let params: API.FrontOrderListInput = {
      pageModel: {
        rows: 20,
        page: pageParam,
        orderInput: [
          queryState.mineSignType === TaskStatus.All
            ? { property: 'isRecommend', order: OrderInputType.Desc }
            : { property: 'lastShelfTime', order: OrderInputType.Desc },
        ],
      },
    };

    return orderServices.getFrontOrderList(params, {
      showLoading: false,
    });
  },
  {
    queryKey: ['orderServices/getFrontOrderList', queryState],
  }
);

function goTaskDetail(item: API.FrontOrderList) {
  Taro.navigateTo({
    url: `${RouterPath.taskDetail}?id=${item.id}`,
  });
}
</script>

<style lang="scss">
@import '@/styles/common.scss';

.mineSign-page-wrapper {
  .task-card-actions-text {
    font-size: 24px;
    line-height: 42px;
  }
}
</style>
